//
//  GPSReadoutViewController.m
//  GPSReadout
//
//  Created by Brad Larson on 2/26/2010.
//

#import "GPSReadoutViewController.h"

@implementation GPSReadoutViewController

- (void)viewDidLoad 
{
	if (matcLocation == nil)
		matcLocation = [[CLLocation alloc] initWithLatitude:43.1209332 longitude:-89.3267498];
	isUpdatingPosition = NO;
	isUpdatingHeading = NO;
    [super viewDidLoad];
}


- (void)didReceiveMemoryWarning {
	// Releases the view if it doesn't have a superview.
    [super didReceiveMemoryWarning];
	
	// Release any cached data, images, etc that aren't in use.
}

- (void)viewDidUnload {
	// Release any retained subviews of the main view.
	// e.g. self.myOutlet = nil;
}

- (void)dealloc 
{
	[matcLocation release];
	[locationManager release];
    [super dealloc];
}

#pragma mark -
#pragma mark Control methods

- (IBAction)startOrStopUpdatingLocation;
{
	if (isUpdatingPosition)
	{
		isUpdatingPosition = NO;
		[startOrStopUpdatingButton setTitle:@"Start updating position" forState:UIControlStateNormal];
		[self.locationManager stopUpdatingLocation];
		
	}
	else
	{
		isUpdatingPosition = YES;
		[startOrStopUpdatingButton setTitle:@"Stop updating position" forState:UIControlStateNormal];
		[self.locationManager startUpdatingLocation];
	}
}

- (IBAction)startOrStopUpdatingHeading;
{
	if (isUpdatingHeading)
	{
		NSLog(@"Stop updating");
		isUpdatingHeading = NO;
		[startOrStopUpdatingHeadingButton setTitle:@"Start updating heading" forState:UIControlStateNormal];
		[self.locationManager stopUpdatingHeading];
		
	}
	else
	{
		NSLog(@"Start updating");
		isUpdatingHeading = YES;
		[startOrStopUpdatingHeadingButton setTitle:@"Stop updating heading" forState:UIControlStateNormal];
		[self.locationManager startUpdatingHeading];
	}
}

#pragma mark -
#pragma mark CLLocationManagerDelegate methods

- (void)locationManager:(CLLocationManager *)manager didFailWithError:(NSError *)error
{
	
}

- (void)locationManager:(CLLocationManager *)manager didUpdateHeading:(CLHeading *)newHeading
{
	magneticHeadingLabel.text = [NSString stringWithFormat:@"%.5f °", newHeading.magneticHeading];
	trueHeadingLabel.text = [NSString stringWithFormat:@"%.5f °", newHeading.trueHeading];
	headingTimeStampLabel.text = [newHeading.timestamp description];
//	headingAccuracy  property
	
//	x  property
//	y  property
//	z  property
	
}

- (void)locationManager:(CLLocationManager *)manager didUpdateToLocation:(CLLocation *)newLocation fromLocation:(CLLocation *)oldLocation
{
	latitudeLabel.text = [NSString stringWithFormat:@"%.5f °", newLocation.coordinate.latitude];
	longitudeLabel.text = [NSString stringWithFormat:@"%.5f °", newLocation.coordinate.longitude];
	altitudeLabel.text = [NSString stringWithFormat:@"%.5f m", newLocation.altitude];
	timeStampLabel.text = [newLocation.timestamp description];
	speedLabel.text = [NSString stringWithFormat:@"%.5f m / s", newLocation.speed];
	distanceFromMATCLabel.text = [NSString stringWithFormat:@"%.5f m", [newLocation getDistanceFrom:matcLocation]];
	
//	horizontalAccuracy  property
//	verticalAccuracy  property
}

- (BOOL)locationManagerShouldDisplayHeadingCalibration:(CLLocationManager *)manager
{
	return NO;
}

#pragma mark -
#pragma mark Accessors

- (CLLocationManager *)locationManager;
{
	if (locationManager != nil)
		return locationManager;
	
	locationManager = [[CLLocationManager alloc] init];
	locationManager.delegate = self;
	
	// This can be kCLLocationAccuracyBest, kCLLocationAccuracyNearestTenMeters, kCLLocationAccuracyHundredMeters, 
	// kCLLocationAccuracyKilometer, or kCLLocationAccuracyThreeKilometers.
	
	locationManager.desiredAccuracy = kCLLocationAccuracyBest;
	
    // Set a movement threshold for new events
    locationManager.distanceFilter = 500;
	
	return locationManager;
}

@end
